<?php
/**
 * Customizer class
 *
 * @package spiffy-lite
 * @subpackage spiffy-lite
 * @since Spiffy Lite 1.0.0
 */

namespace SpiffyLite;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Customizer Class
 */
class Customizer {

	/**
	 * Construct function.
	 *
	 * @var array panels to be added.
	 */
	var $panels = array();

	/**
	 * Construct function.
	 *
	 * @var array sections to be added.
	 */
	var $sections = array();

	/**
	 * Construct function.
	 *
	 * @param mixed $panels .
	 * @param mixed $sections .
	 */
	public function __construct( $panels = array(), $sections = array() ) {
		$this->panels = array_merge( $panels, $this->panels );
		$this->sections = array_merge( $sections, $this->sections );
		add_action( 'customize_register', array( $this, 'spiffy_lite_register_panels_and_sections' ) );
	}

	/**
	 *  Set priority depending on array order
	 */
	public function spiffy_lite_set_priority() {

		$priority = 34;
		foreach ( $this->sections as $key => $value ) {
			$priority++;
			$this->sections[ $key ]['priority'] = $priority;

			if ( isset( $value['options'] ) ) {
				$options_priority = 0;

				foreach ( $value['options'] as $k => $v ) {
					$options_priority++;
					if ( ! isset( $this->sections[ $key ]['options'][ $k ]['priority'] ) ) {
						$this->sections[ $key ]['options'][ $k ]['priority'] = $options_priority;
					}
				}
			}
		}
	}

	/**
	 * Register sections
	 *
	 * @param object $wp_customize .
	 */
	public function spiffy_lite_register_panels_and_sections( $wp_customize ) {

		if ( count( $this->panels ) ) {
			foreach ( $this->panels as $panel ) {
				/**
				 * Add the Theme Options section
				 */
				$wp_customize->add_panel( $panel['id'], array(
					'title' => $panel['title'],
					'description' => $panel['description'],
				) );
			}
		} else {
			/**
			 * Add the Theme Options section
			 */
			$wp_customize->add_panel( 'spiffy_options_panel', array(
				'title' => esc_html__( 'Theme Options', 'spiffy-lite' ),
				'description' => esc_html__( 'Configure your theme settings', 'spiffy-lite' ),
			) );
		}

		foreach ( $this->sections as $section ) {
			$section_id = $section['id'];
			$title = isset( $section['title'] ) ? $section['title'] : 'Section title';
			$desc = isset( $section['description'] ) ? $section['description'] : '';
			$priority = isset( $section['priority'] ) ? $section['priority'] : 35;
			$transport = isset( $section['transport'] ) ?  $section['transport'] : 'refresh';
			$active_callback = isset( $section['active_callback'] ) ?  $section['active_callback'] : '';
			$options = $section['options'];
			$panel = $section['panel'];

			$wp_customize->add_section(
				$section_id,
				array(
					'title' => $title,
					'description' => $desc,
					'priority' => $priority,
					'panel' => $panel,
					'active_callback' => $active_callback,
				)
			);

			foreach ( $options as $option ) {
				$label = $option['label'];
				$option_id = $option['id'];
				$type = isset( $option['type'] ) ? $option['type'] : 'text';
				$default = isset( $option['default'] ) ? $option['default'] : '';
				$priority = isset( $option['priority'] ) ? $option['priority'] : 1;
				$transport = isset( $option['transport'] ) ?  $option['transport'] : 'refresh';
				$description = isset( $option['description'] ) ?  $option['description'] : '';

				if ( 'text' == $type ) {
					$wp_customize->add_setting(
						$option_id,
						array(
							'default' => $default,
							'transport' => $transport,
							'sanitize_callback' => array( $this, 'spiffy_lite_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						$option_id,
						array(
							'label' => $label,
							'section' => $section_id,
							'type' => 'text',
							'description' => $description,
						)
					);
				} elseif ( 'textarea' == $type ) {
					$wp_customize->add_setting(
						$option_id,
						array(
							'default' => $default,
							'transport' => $transport,
							'sanitize_callback' => array( $this, 'spiffy_lite_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						$option_id,
						array(
							'label' => $label,
							'section' => $section_id,
							'type' => 'textarea',
							'description' => $description,
						)
					);
				} elseif ( 'int' == $type ) {
					$wp_customize->add_setting(
						$option_id,
						array(
							'default' => $default,
							'sanitize_callback' => array( $this, 'spiffy_lite_sanitize_int' ),
							'transport' => $transport,
						)
					);
					$wp_customize->add_control(
						$option_id,
						array(
							'label' => $label,
							'section' => $section_id,
							'type' => 'text',
							'description' => $description,
						)
					);
				} elseif ( 'image' == $type ) {
					$wp_customize->add_setting( $option_id,
						array(
							'sanitize_callback' => array( $this, 'spiffy_lite_sanitize_url' ),
							'transport' => $transport,
						)
					);

					$wp_customize->add_control(
						$pixolette_wp_customize_image_control = new \WP_Customize_Image_Control(
							$wp_customize,
							$option_id,
							array(
								'label' => $label,
								'section' => $section_id,
								'settings' => $option_id,
							)
						)
					);
				} elseif ( 'select' == $type ) {
					$wp_customize->add_setting(
						$option_id,
						array(
							'default' => $default,
							'transport' => $transport,
							'sanitize_callback' => array( $this, 'spiffy_lite_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						$option_id,
						array(
							'type' => 'select',
							'label' => $label,
							'section' => $section_id,
							'choices' => $option['choices'],
							'description' => $description,
						)
					);
				} elseif ( 'radio' == $type ) {
					$wp_customize->add_setting(
						$option_id,
						array(
							'default' => $default,
							'transport' => $transport,
							'sanitize_callback' => array( $this, 'spiffy_lite_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						$option_id,
						array(
							'type' => 'radio',
							'label' => $label,
							'section' => $section_id,
							'choices' => $option['choices'],
							'description' => $description,
						)
					);
				} elseif ( 'checkbox' == $type ) {
					$wp_customize->add_setting(
						$option_id,
						array(
							'default' => $default,
							'transport' => $transport,
							'sanitize_callback' => array( $this, 'spiffy_lite_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						$option_id,
						array(
							'type' => 'checkbox',
							'label' => $label,
							'section' => $section_id,
							'description' => $description,
						)
					);
				} elseif ( 'color' == $type ) {
					$wp_customize->add_setting(
						$option_id,
						array(
							'default' => $default,
							'transport' => $transport,
							'sanitize_callback' => 'sanitize_hex_color',
						)
					);
					$wp_customize->add_control(
						new \WP_Customize_Color_Control(
							$wp_customize,
							$option_id,
							array(
								'label' => $label,
								'section' => $section_id,
								'settings' => $option_id,
							)
						)
					);
				} elseif ( 'background' == $type ) {
					$this->background_setting( $option, $section_id, $wp_customize, false );
				}
			}
		}
	}

	/**
	 *  Sanitize integer
	 *
	 * @param string $input .
	 * @return int
	 */
	public function spiffy_lite_sanitize_int( $input ) {
		return intval( $input );
	}

	/**
	 *  Sanitize text
	 *
	 * @param string $input .
	 * @return int
	 */
	public function spiffy_lite_sanitize_text( $input ) {
		return sanitize_text_field( $input );
	}

	/**
	 *  Sanitize image
	 *
	 * @param string $input .
	 * @return int
	 */
	public function spiffy_lite_sanitize_url( $input ) {
		return esc_url( $input );
	}
}
