<?php
/**
 * Customizer init
 *
 * @package spiffy-lite
 * @subpackage customizer
 * @since Spiffy Lite 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require get_template_directory() . '/customizer/class-customizer.php';
use SpiffyLite\Customizer as SpiffyLiteCustomizer;

/**
 * Init customizer from PixoletteFramework
 *
 * @var array sections to be added.
 */
function spiffy_lite_init_customizer() {

	$spiffy_lite_customizer_panels['spiffy_lite_theme_options'] = array(
		'id' => 'spiffy_lite_theme_options',
		'title' => esc_html__( 'Theme Options', 'spiffy-lite' ),
		'description' => esc_html__( 'Configure your theme settings', 'spiffy-lite' ),
	);

	/**
	 * Define cusomizer options for Spiffy theme.
	 * pix_sp prefix to be sure we have unique ids
	 *
	 * @var $spiffy_lite_customizer_options
	 */
	$spiffy_lite_customizer_options['spiffy_lite_blog'] = array(
		'id' => 'spiffy_lite_blog',
		'title' => esc_html__( 'Display options', 'spiffy-lite' ),
		'panel' => 'spiffy_lite_theme_options',
		'options' => array(
			'spiffy_lite_blog_layout' => array(
				'id' => 'spiffy_lite_blog_layout',
				'label' => esc_html__( 'Blog layout', 'spiffy-lite' ),
				'type' => 'select',
				'transport' => 'refresh',
				'choices' => array(
					'standard' => esc_html__( 'Standard(boxed)', 'spiffy-lite' ),
					'sidebar-left' => esc_html__( 'Sidebar on left(boxed)', 'spiffy-lite' ),
					'sidebar-right' => esc_html__( 'Sidebar on right(boxed)', 'spiffy-lite' ),
				),
				'default' => 'standard',
			),
			'spiffy_lite_blog_hide_date' => array(
				'label' => esc_html__( 'Hide date', 'spiffy-lite' ),
				'id' => 'spiffy_lite_blog_hide_date',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
			'spiffy_lite_blog_hide_author' => array(
				'label' => esc_html__( 'Hide author', 'spiffy-lite' ),
				'id' => 'spiffy_lite_blog_hide_author',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
			'spiffy_lite_blog_hide_category' => array(
				'label' => esc_html__( 'Hide category', 'spiffy-lite' ),
				'id' => 'spiffy_lite_blog_hide_category',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
			'spiffy_lite_blog_hide_comments_count' => array(
				'label' => esc_html__( 'Hide comments count', 'spiffy-lite' ),
				'id' => 'spiffy_lite_blog_hide_comments_count',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
			'spiffy_lite_blog_hide_tags' => array(
				'label' => esc_html__( 'Hide tags', 'spiffy-lite' ),
				'id' => 'spiffy_lite_blog_hide_tags',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
			'spiffy_lite_hide_featured_image' => array(
				'label' => esc_html__( 'Hide featured image(on single post page)', 'spiffy-lite' ),
				'id' => 'spiffy_lite_hide_featured_image',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
			'spiffy_lite_hide_breadcrumbs' => array(
				'label' => esc_html__( 'Hide breadcrumbs', 'spiffy-lite' ),
				'id' => 'spiffy_lite_hide_breadcrumbs',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
			'spiffy_lite_display_navigation_for_pages' => array(
				'label' => esc_html__( 'Display navigation for pages?', 'spiffy-lite' ),
				'id' => 'spiffy_lite_display_navigation_for_pages',
				'type' => 'checkbox',
				'transport' => 'postMessage',
			),
		),
	);

	$spiffy_lite_customizer_options['spiffy_lite_header'] = array(
		'id' => 'spiffy_lite_header',
		'title' => esc_html__( 'Header options', 'spiffy-lite' ),
		'panel' => 'spiffy_lite_theme_options',
		'options' => array(
			'spiffy_lite_sticky_header' => array(
				'label' => esc_html__( 'Sticky header', 'spiffy-lite' ),
				'id' => 'spiffy_lite_sticky_header',
				'type' => 'checkbox',
			),
			'spiffy_lite_logo' => array(
				'id' => 'spiffy_lite_logo',
				'label' => esc_html__( 'Header Logo', 'spiffy-lite' ),
				'type' => 'image',
				'transport' => 'postMessage',
			),
		),
	);

	$spiffy_lite_customizer_options['spiffy_lite_footer'] = array(
		'id' => 'spiffy_lite_footer',
		'title' => esc_html__( 'Footer options', 'spiffy-lite' ),
		'panel' => 'spiffy_lite_theme_options',
		'options' => array(
			'spiffy_lite_footer_layout' => array(
				'id' => 'spiffy_lite_footer_layout',
				'label' => esc_html__( 'Footer layout', 'spiffy-lite' ),
				'type' => 'select',
				'choices' => array(
					'0' => esc_html__( 'No column for widgets', 'spiffy-lite' ),
					'1' => esc_html__( '1 column', 'spiffy-lite' ),
					'2' => esc_html__( '2 columns', 'spiffy-lite' ),
					'3' => esc_html__( '3 columns', 'spiffy-lite' ),
					'4' => esc_html__( '4 columns', 'spiffy-lite' ),
				),
				'default' => '0',
				'transport' => 'refresh',
			),
			'spiffy_lite_scroll_to_top' => array(
				'label' => esc_html__( 'Display scroll to top button?', 'spiffy-lite' ),
				'id' => 'spiffy_lite_scroll_to_top',
				'type' => 'radio',
				'choices' => array(
					'yes' => esc_html__( 'Yes', 'spiffy-lite' ),
					'no' => esc_html__( 'No', 'spiffy-lite' ),
				),
				'default' => 'yes',
				'transport' => 'postMessage',
			),
		),
	);

	$spiffy_lite_customizer_options['spiffy_lite_featured_posts'] = array(
		'id' => 'spiffy_lite_featured_posts',
		'title' => esc_html__( 'Front page featured content', 'spiffy-lite' ),
		'panel' => 'spiffy_lite_theme_options',
		'description' => esc_html__( 'Options for featured on front page', 'spiffy-lite' ),
		'active_callback' => 'is_front_page',
		'options' => array(
			'spiffy_lite_featured_post_1_alignment' => array(
				'id' => 'spiffy_lite_featured_post_1_alignment',
				'label' => esc_html__( 'Text alignment', 'spiffy-lite' ),
				'type' => 'radio',
				'choices' => array(
					'left' => esc_html__( 'Left', 'spiffy-lite' ),
					'right' => esc_html__( 'Right', 'spiffy-lite' ),
				),
				'default' => 'left',
				'transport' => 'postMessage',
			),
			'spiffy_lite_scroll_down_button' => array(
				'label' => esc_html__( 'Display scroll down button?', 'spiffy-lite' ),
				'id' => 'spiffy_lite_scroll_down_button',
				'type' => 'radio',
				'choices' => array(
					'yes' => esc_html__( 'Yes', 'spiffy-lite' ),
					'no' => esc_html__( 'No', 'spiffy-lite' ),
				),
				'default' => 'yes',
				'transport' => 'postMessage',
			),
			'spiffy_lite_slideshow_autoplay' => array(
				'label' => esc_html__( 'Set AutoPlay for slideshow?', 'spiffy-lite' ),
				'description' => esc_html__( 'Only if featured pages are displayed as slider', 'spiffy-lite' ),
				'id' => 'spiffy_lite_slideshow_autoplay',
				'type' => 'radio',
				'choices' => array(
					'yes' => esc_html__( 'Yes', 'spiffy-lite' ),
					'no' => esc_html__( 'No', 'spiffy-lite' ),
				),
				'default' => 'yes',
				'transport' => 'refresh',
			),
			'spiffy_lite_slideshow_autoplay_speed' => array(
				'label' => esc_html__( 'AutoPlay speed?', 'spiffy-lite' ),
				'description' => esc_html__( 'Speed in seconds. Default is set to 4 seconds. Example values: 1 -> slide will change each second. 2.3 -> slide will change each 2.3 seconds. (Only if featured pages are displayed as slider and AutoPlay is enabled)', 'spiffy-lite' ),
				'id' => 'spiffy_lite_slideshow_autoplay_speed',
				'type' => 'text',
				'transport' => 'refresh',
			),
		),
	);

	$spiffy_lite_customizer_options['spiffy_lite_misc'] = array(
		'id' => 'spiffy_lite_misc',
		'title' => esc_html__( 'Miscellaneous', 'spiffy-lite' ),
		'panel' => 'spiffy_lite_theme_options',
		'description' => esc_html__( 'Miscellaneous options', 'spiffy-lite' ),
		'options' => array(
			'spiffy_lite_analytics' => array(
				'id' => 'spiffy_lite_analytics',
				'label' => esc_html__( 'Analytics ID', 'spiffy-lite' ),
				'description' => esc_html__( 'Insert here only ID(for example: UA-11122233-1)', 'spiffy-lite' ),
				'type' => 'text',
				'transport' => 'postMessage',
			),
		),
	);

	new SpiffyLiteCustomizer( $spiffy_lite_customizer_panels, $spiffy_lite_customizer_options );

}
if ( is_user_logged_in() ) {
	add_action( 'after_setup_theme', 'spiffy_lite_init_customizer' );
}
