<?php
/**
 * Theme setup
 *
 * @package spiffy-lite
 * @subpackage functions
 * @since Spiffy Lite 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Theme setup function.
 */
function spiffy_lite_theme_init() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 */
	load_theme_textdomain( 'spiffy-lite', get_template_directory() . '/languages' );

	add_theme_support( 'post-thumbnails' );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'status',
		'audio',
		'chat',
	) );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	if ( ! isset( $content_width ) ) {
		$content_width = 1170;
	}

	// Add excerpt option.
	add_post_type_support( 'page', 'excerpt' );

	// Menus.
	register_nav_menu( 'spiffy_menu_1', 'Menu displayed in header' );
	register_nav_menu( 'spiffy_menu_4', 'Menu displayed on mobile devices' );

	// Indicate widget sidebars can use selective refresh in the Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );
}
add_action( 'after_setup_theme', 'spiffy_lite_theme_init' );

/**
 * Theme setup function.
 */
function spiffy_lite_editor_style() {
	add_editor_style( get_template_directory_uri() . '/assets/css/style.css' );
}
add_action( 'init', 'spiffy_lite_editor_style' );

/**
 * Customizer additions.
 */
require get_template_directory() . '/customizer/init.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/functions/jetpack.php';

/**
 * Load plugin enhancement file to display admin notices.
 */
require get_template_directory() . '/functions/plugin-enhancements.php';
