<?php
/**
 * Default body template
 *
 * @package spiffy-lite
 * @subpackage tempolate-parts
 * @since Spiffy Lite 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
$is_full = false;
$has_sidebar = false;
$hide_featured_image = true;
$container_type = spiffy_lite_get_theme_mod( 'spiffy_lite_blog_layout' );
if ( false !== strpos( $container_type, 'fullwidth' ) || ! $container_type ) {
	$is_full = true;
}
if ( false !== strpos( $container_type, 'sidebar' ) ) {
	$has_sidebar = true;
}
$hide_featured_image = spiffy_lite_get_theme_mod( 'spiffy_lite_hide_featured_image' );
$hide_breadcrumbs = spiffy_lite_get_theme_mod( 'spiffy_lite_hide_breadcrumbs' );
$display_navigation = spiffy_lite_get_theme_mod( 'spiffy_lite_display_navigation_for_pages' );
?>


<div id="post-<?php the_ID(); ?>" <?php post_class( 'spf-single' ); ?>>
	<?php if ( ! $hide_featured_image && has_post_thumbnail() ) : ?>
		<div class="row no-gutter-sm">
			<div class="col-xs-12">
				<div class="spf-featured-image text-center">
					<?php echo the_post_thumbnail( 'full' ); ?>
				</div>
			</div>
		</div>
	<?php endif; ?>
	<?php if ( is_search() ) : ?>
		<a href="<?php the_permalink(); ?>"><?php the_title( '<h1 class="spiffy-page-title word-underline no-hover">', '</h1>' ); ?></a>
	<?php else : ?>
		<?php the_title( '<h1 class="spiffy-page-title">', '</h1>' ); ?>
	<?php endif; ?>
	<?php
	if ( ! $hide_breadcrumbs ) :
		spiffy_lite_display_breadcrumbs();
	endif;
	?>
	<?php is_page() ? '' : get_template_part( 'template-parts/content-meta', 'header' ); ?>
	<div class="spiffy-page-content">
		<?php the_content( esc_html( 'Read more', 'spiffy-lite' ) ); ?>
		<?php
		$defaults = array(
			'before'           => '<p><span class="word-underline">' . esc_html__( 'Post pages:', 'spiffy-lite' ) . '</span>',
			'after'            => '</p>',
			'link_before'      => '',
			'link_after'       => '',
			'next_or_number'   => 'number',
			'separator'        => ' ',
			'nextpagelink'     => esc_html__( 'Next page', 'spiffy-lite' ),
			'previouspagelink' => esc_html__( 'Previous page', 'spiffy-lite' ),
			'pagelink'         => '%',
			'echo'             => 1,
		);
		wp_link_pages( $defaults );
		?>
	</div>
	<div class="spf-tags-container">
		<?php the_tags( 'Tags: ', ' &#8226; ', '' ); ?>
	</div>
</div>
<div class="spf-comments-container">
	<?php
	// If comments are open or we have at least one comment, load up the comment template.
	if ( comments_open() || get_comments_number() ) :
		comments_template();
	endif;

	if ( is_single() || is_page() && $display_navigation ) :
		the_post_navigation(array(
			'next_text' => '<span class="meta-nav" aria-hidden="true">' . esc_html__( 'Next:', 'spiffy-lite' ) . '</span><span class="screen-reader-text">' . esc_html__( 'Next post:', 'spiffy-lite' ) . '</span><span class="post-title">%title</span>',
			'prev_text' => '<span class="meta-nav" aria-hidden="true">' . esc_html__( 'Previous:', 'spiffy-lite' ) . '</span><span class="screen-reader-text">' . esc_html__( 'Previous post:', 'spiffy-lite' ) . '</span><span class="post-title">%title</span>',
		));
	endif;
	?>
</div>
